#version 460

#include "/lib/settings.glsl"

const mat4 TEXTURE_MATRIX_2 = mat4(vec4(0.00390625, 0.0, 0.0, 0.0), vec4(0.0, 0.00390625, 0.0, 0.0), vec4(0.0, 0.0, 0.00390625, 0.0), vec4(0.03125, 0.03125, 0.03125, 1.0));
in vec3 vaPosition, vaNormal, mc_Entity;
in vec4 vaColor;
in vec2 vaUV0;
in ivec2 vaUV2;
uniform mat4 modelViewMatrix, projectionMatrix;
uniform mat3 normalMatrix;
uniform vec3 chunkOffset;

out vec4 tintColor;
out vec2 texCoord, lmcoord;

out float emission;

float getEmission(in float blockEntityId) {
	if (blockEntityId == 1.0) {
		return 1.0;
	} else {
		return 0.0;
	}
}

float getIsRedstoneBlock(in float blockEntityId) {
	#ifdef GLOWING_REDSTONE_BLOCK
		if (blockEntityId == 2.0) {
			return 1.0;
		} else {
			return 0.0;
		}
	#else
		return 0.0;
	#endif
}

float getIsEmeraldBlock(in float blockEntityId) {
	#ifdef GLOWING_EMERALD_BLOCK
		if (blockEntityId == 3.0) {
			return 1.0;
		} else {
		 return 0.0;
		}
	#else
		return 0.0;
	#endif
}

float getIsLapisBlock(in float blockEntityId) {
	#ifdef GLOWING_LAPIS_BLOCK
		if (blockEntityId == 4.0) {
			return 1.0;
		} else {
			return 0.0;
		}
	#else
		return 0.0;
	#endif
}

#ifndef NO_SHADOWS
	out vec3 normal;
#endif

void main() {
	vec4 position = projectionMatrix * modelViewMatrix * vec4(vaPosition + chunkOffset, 1.0);

	gl_Position = position;
	texCoord = vaUV0;
	tintColor = vaColor * vec4(1.0, 1.0, 1.0, 0.7);
	lmcoord = (TEXTURE_MATRIX_2 * vec4(vaUV2, 0.0, 1.0)).xy;

	emission = min(getEmission(mc_Entity.r) + getIsRedstoneBlock(mc_Entity.r) + getIsEmeraldBlock(mc_Entity.r) + getIsLapisBlock(mc_Entity.r), 1.0);

	#ifndef NO_SHADOWS
		normal = normalize(normalMatrix * vaNormal) * 0.5 + 0.5;
	#endif
}