#if TONEMAP == 3 // uncharted2Tonemap
	vec3 uncharted2Math(in vec3 color) {
		return ((color * (0.15 * color + 0.05) + 0.004) / (color * (0.15 * color + 0.5) + 0.06)) - 0.02 / 0.3;
	}
#endif

vec3 tonemap(in vec3 color) {
	#if TONEMAP == 0 // reinhardJodieTonemap
		color = pow(color, vec3(TONEMAP_CURVE));

		float luminance = dot(color, vec3(0.2125, 0.7154, 0.0721)) + 1.0;

		vec3 tv = color / (1.0 + color);

		return pow(mix(color / luminance, tv, tv), vec3(1.0 / (GAMMA * TONEMAP_CURVE)));
	#elif TONEMAP == 1 // burgessHDRTonemap
		color = max(mix(color * 1.2, color * 0.6, color) - 0.004, vec3(0.0));

		return pow(color * (6.2 * color + 0.05)) / (color * (6.2 * color + 2.3) + 0.06, vec3(1.0 / GAMMA));
	#elif TONEMAP == 2 // ACESTonemap
		const float a = 2.51;
		const float b = 0.03;
		const float c = 2.43;
		const float d = 0.59;
		const float e = 0.14;

		return pow(clamp((color * (a * color + b)) / (color * (c * color + d) + e), 0.0, 1.0), vec3(1.0 / GAMMA));
	#elif TONEMAP == 3 // uncharted2Tonemap
		return pow(uncharted2Math(color * 2.0) / uncharted2Math(vec3(11.2)), vec3(1.0 / GAMMA));
	#elif TONEMAP == 4 // lottesTonemap
		const vec3 hdrMax = vec3(8.0);
		const vec3 midIn = vec3(0.18);
		const vec3 midOut = vec3(0.267);

		const vec3 a = vec3(1.6);
		const vec3 d = a * vec3(0.977);

		const vec3 b = (-pow(midIn, a) + pow(hdrMax, a) * midOut) / ((pow(hdrMax, d) - pow(midIn, d)) * midOut);
		const vec3 c = (pow(hdrMax, d) * pow(midIn, a) - pow(hdrMax, a) * pow(midIn, d) * midOut) / ((pow(hdrMax, d) - pow(midIn, d)) * midOut);

		return pow(pow(color, a) / (pow(color, d) * b + c), vec3(1.0 / GAMMA));
	#elif TONEMAP == 5 // filmicTonemap
		color = max(vec3(0.0), color - 0.004);

		return color * (6.2 * color + 0.5) / (color * (6.2 * color + 1.7) + 0.06);
	#else
		return pow(color, vec3(1.0 / GAMMA));
	#endif
}